==> openshift-model-5.7.3-sources.jar: io/fabric8/openshift/api/model/OperatorHubStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OperatorHubStatusBuilder extends io.fabric8.openshift.api.model.OperatorHubStatusFluentImpl<io.fabric8.openshift.api.model.OperatorHubStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.OperatorHubStatus,io.fabric8.openshift.api.model.OperatorHubStatusBuilder>{
  public OperatorHubStatusBuilder() {
    this(false);
  }
  public OperatorHubStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new OperatorHubStatus(), validationEnabled);
  }
  public OperatorHubStatusBuilder(io.fabric8.openshift.api.model.OperatorHubStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorHubStatusBuilder(io.fabric8.openshift.api.model.OperatorHubStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OperatorHubStatus(), validationEnabled);
  }
  public OperatorHubStatusBuilder(io.fabric8.openshift.api.model.OperatorHubStatusFluent<?> fluent,io.fabric8.openshift.api.model.OperatorHubStatus instance) {
    this(fluent, instance, false);
  }
  public OperatorHubStatusBuilder(io.fabric8.openshift.api.model.OperatorHubStatusFluent<?> fluent,io.fabric8.openshift.api.model.OperatorHubStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withSources(instance.getSources()); 
    this.validationEnabled = validationEnabled; 
  }
  public OperatorHubStatusBuilder(io.fabric8.openshift.api.model.OperatorHubStatus instance) {
    this(instance,false);
  }
  public OperatorHubStatusBuilder(io.fabric8.openshift.api.model.OperatorHubStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withSources(instance.getSources()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.OperatorHubStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.OperatorHubStatus build() {
    OperatorHubStatus buildable = new OperatorHubStatus(fluent.getSources());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperatorHubStatusBuilder that = (OperatorHubStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-5.10.1-sources.jar: io/fabric8/openshift/api/model/OperatorHubStatusBuilder.java <==
package io.fabric8.openshift.api.model;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class OperatorHubStatusBuilder extends io.fabric8.openshift.api.model.OperatorHubStatusFluentImpl<io.fabric8.openshift.api.model.OperatorHubStatusBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.OperatorHubStatus,io.fabric8.openshift.api.model.OperatorHubStatusBuilder>{
  public OperatorHubStatusBuilder() {
    this(false);
  }
  public OperatorHubStatusBuilder(java.lang.Boolean validationEnabled) {
    this(new OperatorHubStatus(), validationEnabled);
  }
  public OperatorHubStatusBuilder(io.fabric8.openshift.api.model.OperatorHubStatusFluent<?> fluent) {
    this(fluent, false);
  }
  public OperatorHubStatusBuilder(io.fabric8.openshift.api.model.OperatorHubStatusFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new OperatorHubStatus(), validationEnabled);
  }
  public OperatorHubStatusBuilder(io.fabric8.openshift.api.model.OperatorHubStatusFluent<?> fluent,io.fabric8.openshift.api.model.OperatorHubStatus instance) {
    this(fluent, instance, false);
  }
  public OperatorHubStatusBuilder(io.fabric8.openshift.api.model.OperatorHubStatusFluent<?> fluent,io.fabric8.openshift.api.model.OperatorHubStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withSources(instance.getSources()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public OperatorHubStatusBuilder(io.fabric8.openshift.api.model.OperatorHubStatus instance) {
    this(instance,false);
  }
  public OperatorHubStatusBuilder(io.fabric8.openshift.api.model.OperatorHubStatus instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withSources(instance.getSources()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.OperatorHubStatusFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.OperatorHubStatus build() {
    OperatorHubStatus buildable = new OperatorHubStatus(fluent.getSources());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    OperatorHubStatusBuilder that = (OperatorHubStatusBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
